@@ -1,23 +1,10 @@
 /*
-    Copyright (c) 2015 Stephen Kelly <steveire@gmail.com>
-    Copyright (c) 2015 David Faure <faure@kde.org>
-    Copyright (c) 2016 Ableton AG <info@ableton.com>
-        Author Stephen Kelly <stephen.kelly@ableton.com>
+    SPDX-FileCopyrightText: 2015 Stephen Kelly <steveire@gmail.com>
+    SPDX-FileCopyrightText: 2015 David Faure <faure@kde.org>
+    SPDX-FileCopyrightText: 2016 Ableton AG <info@ableton.com>
+    SPDX-FileContributor: Stephen Kelly <stephen.kelly@ableton.com>
 
-    This library is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This library is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include <QTest>
@@ -36,7 +23,7 @@ class KSelectionProxyModelTest : public QObject
 {
   Q_OBJECT
 public:
-  KSelectionProxyModelTest(QObject* parent = 0)
+  KSelectionProxyModelTest(QObject* parent = nullptr)
     : QObject(parent),
       days({
           QStringLiteral("Monday"),
